/**
 * @file
 * A JavaScript file for the theme.
 *
 * In order for this JavaScript to be loaded on pages, see the instructions in
 * the README.txt next to this file.
 */

// JavaScript should be made compatible with libraries other than jQuery by
// wrapping it with an "anonymous closure". See:
// - https://drupal.org/node/1446420
// - http://www.adequatelygood.com/2010/3/JavaScript-Module-Pattern-In-Depth


// h2 are topics; state is identified by class (contracted, expanded)
// initial state for all h2 are contracted
//
// .subwrapper is the topic information, initially hidden (class=hide-details)
// when h2 is clicked, the .subwrapper below is is set to show-details
//
// Initial state:
//    all h2 have class contracted
//    all .subwrapper have class hide-details
//
// Click handler for h2:
//    if h2 is currently expanded, set to contracted, set .subwrapper to hide-details
//    check other h2 for expanded; set them to contracted and .subwrapper to hide-details


(function ($, Drupal, window, document, undefined) {
  // pet guide section expanded topics
  Drupal.behaviors.guideSectionTopics = {
    attach: function (context, settings) {
      let dbg = false;   // set true for console debugging

      // page_2 is active section view
      if (dbg) console.log('process page 2 for ' + context);
      $('.view-id-pet_guides.view-display-id-page_2 .section-wrapper', context).once('customSectionWrapper').each( function(index) {
        var thisSection = $(this);
        $(thisSection).find('h2').click(function() {
          // clicked on topic
          var clicked = $(this);
          if (dbg) console.log('clicked on topic: ' + clicked.attr('id') + ' (' + clicked.prop("classList") + ')');
          $.each($('.view-id-pet_guides.view-display-id-page_2 .section-wrapper h2.expanded'), function(index) {
            if (dbg) console.log('this: ' + $(this).attr('id') + ' clicked: ' + clicked.attr('id'));
            if ($(this).attr('id') != clicked.attr('id')) {
              if (dbg) console.log('-- different ' + $(this).attr('id'));
              $(this).removeClass('expanded').addClass('contracted');
              let subw = $(this).parent().find('.subwrapper');
              subw.removeClass('show-details').addClass('hide-details');
            }
          });
          // set expanded/contracted
          if (clicked.hasClass('expanded')) {
            if (dbg) console.log('ex1');
            if (dbg) console.log('wrap: ' + clicked.parent().prop("classList"));
            if (dbg) console.log('wrap: ' + clicked.parent().find(".subwrapper").prop("classList"));
            // contract it
            clicked.removeClass('expanded').addClass('contracted');
            clicked.parent().find(".subwrapper").removeClass('show-details').addClass('hide-details');
            /***
             // current expanded topic - hide it
             $(thisSection).find(".view-id-pet_guides.view-display-id-page_2 .subwrapper").removeClass('show-details').addClass('hide-details');
             clicked.removeClass('show-details').addClass('hide-details');
             // sidebar link
             $("#block-views-guides-block-1 .item-list ul li a").removeClass('current');
             ***/
          }
          else {
            // on a different topic
            // hide other topics, show this topic
            if (dbg) console.log('con1');
            $(thisSection).find('h2').removeClass('contracted').addClass('expanded');
            //$('.view-id-pet_guides.view-display-id-page_2 .section-wrapper').find(".subwrapper").removeClass('show-details');
            $(thisSection).find(".subwrapper").removeClass('hide-details').addClass('show-details');
            clicked.removeClass('hide-details').addClass('show-details');
            // change URL hash so content is on top
            window.location.hash = clicked.attr('id');
            // sidebar link
            $("#block-views-guides-block-1 .item-list ul li a").removeClass('current');
            $("#block-views-guides-block-1 .item-list ul li a." + clicked.attr('id')).addClass('current');
          }
         });
      });
    }
  };

})(jQuery, Drupal, this, this.document);
